@@ -1,6 +1,6 @@
 # test env vars
 
-print "Content-type: text/plain\r\n\r\n";
+print "Content-type: text/plain\n\n";
 print exists $ENV{QUERY_STRING} && $ENV{QUERY_STRING};
 
 __END__
