@@ -1,8 +1,9 @@
-/* Copyright 2001-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -84,7 +85,7 @@ static int is_modperl_filter(ap_filter_t *f)
 {
     const char *name = f->frec->name;
 
-    /* frec->name is always lowercased */ 
+    /* frec->name is always lowercased */
     if (!strcasecmp(name, MP_FILTER_CONNECTION_INPUT_NAME)  ||
         !strcasecmp(name, MP_FILTER_CONNECTION_OUTPUT_NAME) ||
         !strcasecmp(name, MP_FILTER_REQUEST_INPUT_NAME)     ||
@@ -104,7 +105,7 @@ MP_INLINE static apr_status_t send_input_eos(modperl_filter_t *filter)
     APR_BRIGADE_INSERT_TAIL(filter->bb_out, b);
     ((modperl_filter_ctx_t *)filter->f->ctx)->sent_eos = 1;
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "write out: EOS bucket\n", MP_FILTER_NAME(filter->f));
+               "write out: EOS bucket", MP_FILTER_NAME(filter->f));
     return APR_SUCCESS;
 }
 
@@ -114,7 +115,7 @@ MP_INLINE static apr_status_t send_input_flush(modperl_filter_t *filter)
     apr_bucket *b = apr_bucket_flush_create(ba);
     APR_BRIGADE_INSERT_TAIL(filter->bb_out, b);
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "write out: FLUSH bucket\n", MP_FILTER_NAME(filter->f));
+               "write out: FLUSH bucket", MP_FILTER_NAME(filter->f));
     return APR_SUCCESS;
 }
 
@@ -127,7 +128,7 @@ MP_INLINE static apr_status_t send_output_eos(ap_filter_t *f)
     APR_BRIGADE_INSERT_TAIL(bb, b);
     ((modperl_filter_ctx_t *)f->ctx)->sent_eos = 1;
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "write out: EOS bucket in separate bb\n", MP_FILTER_NAME(f));
+               "write out: EOS bucket in separate bb", MP_FILTER_NAME(f));
     return ap_pass_brigade(f->next, bb);
 }
 
@@ -139,7 +140,7 @@ MP_INLINE static apr_status_t send_output_flush(ap_filter_t *f)
     apr_bucket *b = apr_bucket_flush_create(ba);
     APR_BRIGADE_INSERT_TAIL(bb, b);
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "write out: FLUSH bucket in separate bb\n", MP_FILTER_NAME(f));
+               "write out: FLUSH bucket in separate bb", MP_FILTER_NAME(f));
     return ap_pass_brigade(f, bb);
 }
 
@@ -164,7 +165,7 @@ MP_INLINE apr_status_t modperl_wbucket_pass(modperl_wbucket_t *wb,
         const char *body;
         int status;
 
-        MP_TRACE_f(MP_FUNC, "\n\n\tparsing headers: %db [%s]\n", len,
+        MP_TRACE_f(MP_FUNC, "parsing headers: %db [%s]", len,
                    MP_TRACE_STR_TRUNC(wb->pool, buf, len));
 
         status = modperl_cgi_header_parse(r, (char *)buf, &len, &body);
@@ -208,9 +209,9 @@ MP_INLINE apr_status_t modperl_wbucket_pass(modperl_wbucket_t *wb,
         APR_BRIGADE_INSERT_TAIL(bb, bucket);
     }
 
-    MP_TRACE_f(MP_FUNC, "\n\n\twrite out: %db [%s]\n"
-               "\t\tfrom %s\n\t\tto %s filter handler\n",
-               len, 
+    MP_TRACE_f(MP_FUNC, "\n\n\twrite out: %db [%s]"
+               "\t\tfrom %s\n\t\tto %s filter handler",
+               len,
                MP_TRACE_STR_TRUNC(wb->pool, buf, len),
                ((wb->r && wb->filters == &wb->r->output_filters)
                    ? "response handler" : "current filter handler"),
@@ -342,7 +343,7 @@ modperl_filter_t *modperl_filter_new(ap_filter_t *f,
 
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
                "new: %s %s filter (modperl_filter_t *0x%lx), "
-               "f (ap_filter_t *0x%lx)\n",
+               "f (ap_filter_t *0x%lx)",
                MP_FILTER_NAME(f),
                MP_FILTER_TYPE(filter),
                MP_FILTER_MODE(filter),
@@ -403,10 +404,12 @@ int modperl_filter_resolve_init_handler(pTHX_ modperl_handler_t *handler,
         FREETMPS;LEAVE;
 
         if (init_handler) {
-            MP_TRACE_h(MP_FUNC, "found init handler %s\n",
+            modperl_mgv_resolve(aTHX_ init_handler, p, init_handler->name, 1);
+
+            MP_TRACE_h(MP_FUNC, "found init handler %s",
                        modperl_handler_name(init_handler));
 
-            if (!init_handler->attrs & MP_FILTER_INIT_HANDLER) {
+            if (!(init_handler->attrs & MP_FILTER_INIT_HANDLER)) {
                 Perl_croak(aTHX_ "handler %s doesn't have "
                            "the FilterInitHandler attribute set",
                            modperl_handler_name(init_handler));
@@ -426,7 +429,7 @@ int modperl_filter_resolve_init_handler(pTHX_ modperl_handler_t *handler,
 
 static int modperl_run_filter_init(ap_filter_t *f,
                                    modperl_filter_mode_e mode,
-                                   modperl_handler_t *handler) 
+                                   modperl_handler_t *handler)
 {
     AV *args = Nullav;
     int status;
@@ -437,9 +440,9 @@ static int modperl_run_filter_init(ap_filter_t *f,
     apr_pool_t  *p = r ? r->pool : c->pool;
     modperl_filter_t *filter = modperl_filter_new(f, NULL, mode, 0, 0, 0);
 
-    MP_dINTERP_SELECT(r, c, s);    
+    MP_dINTERP_SELECT(r, c, s);
 
-    MP_TRACE_h(MP_FUNC, "running filter init handler %s\n",
+    MP_TRACE_h(MP_FUNC, "running filter init handler %s",
                modperl_handler_name(handler));
 
     modperl_handler_make_args(aTHX_ &args,
@@ -464,12 +467,29 @@ static int modperl_run_filter_init(ap_filter_t *f,
     MP_INTERP_PUTBACK(interp);
 
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "return: %d\n", modperl_handler_name(handler), status);
+               "return: %d", modperl_handler_name(handler), status);
 
-    return status;  
+    return status;
 }
 
 
+#define MP_RUN_CROAK_RESET_OK(func)                                     \
+    {                                                                   \
+        apr_status_t rc = func(filter);                                 \
+        if (rc != APR_SUCCESS) {                                        \
+            if (APR_STATUS_IS_ECONNRESET(rc) ||                         \
+                APR_STATUS_IS_ECONNABORTED(rc)) {                       \
+                ap_log_error(APLOG_MARK, APLOG_INFO, 0, s,              \
+                             "Apache2::Filter internal flush got: %s",  \
+                             modperl_error_strerror(aTHX_ rc));         \
+            }                                                           \
+            else {                                                      \
+                modperl_croak(aTHX_ rc,                                 \
+                              "Apache2::Filter internal flush");        \
+            }                                                           \
+        }                                                               \
+    }
+
 int modperl_run_filter(modperl_filter_t *filter)
 {
     AV *args = Nullav;
@@ -527,6 +547,15 @@ int modperl_run_filter(modperl_filter_t *filter)
 
     if (filter->mode == MP_INPUT_FILTER_MODE) {
         if (filter->bb_in) {
+            if (status == DECLINED) {
+                /* make sure the filter doesn't try to make mod_perl
+                 * pass the bucket brigade through after it called
+                 * $f->read(), since it causes a pre-fetch of the
+                 * bb */
+                modperl_croak(aTHX_ MODPERL_FILTER_ERROR,
+                              "a filter calling $f->read "
+                              "must return OK and not DECLINED");
+            }
             /* in the streaming mode filter->bb_in is populated on the
              * first modperl_input_filter_read, so it must be
              * destroyed at the end of the filter invocation
@@ -534,12 +563,10 @@ int modperl_run_filter(modperl_filter_t *filter)
             apr_brigade_destroy(filter->bb_in);
             filter->bb_in = NULL;
         }
-        MP_RUN_CROAK(modperl_input_filter_flush(filter),
-                     "Apache2::Filter");
+        MP_RUN_CROAK_RESET_OK(modperl_input_filter_flush);
     }
     else {
-        MP_RUN_CROAK(modperl_output_filter_flush(filter),
-                     "Apache2::Filter");
+        MP_RUN_CROAK_RESET_OK(modperl_output_filter_flush);
     }
 
     MP_FILTER_RESTORE_ERRSV(errsv);
@@ -547,12 +574,11 @@ int modperl_run_filter(modperl_filter_t *filter)
     MP_INTERP_PUTBACK(interp);
 
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "return: %d\n", modperl_handler_name(handler), status);
+               "return: %d", modperl_handler_name(handler), status);
 
     return status;
 }
 
-
 /* unrolled APR_BRIGADE_FOREACH loop */
 
 #define MP_FILTER_EMPTY(filter)                 \
@@ -577,7 +603,7 @@ MP_INLINE static int get_bucket(modperl_filter_t *filter)
 {
     if (!filter->bb_in || MP_FILTER_EMPTY(filter)) {
         MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-                   "read in: bucket brigade is empty\n",
+                   "read in: bucket brigade is empty",
                    MP_FILTER_NAME(filter->f));
         return 0;
     }
@@ -599,7 +625,7 @@ MP_INLINE static int get_bucket(modperl_filter_t *filter)
 
     if (MP_FILTER_IS_EOS(filter)) {
         MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-                   "read in: EOS bucket\n",
+                   "read in: EOS bucket",
                    MP_FILTER_NAME(filter->f));
 
         filter->seen_eos = 1;
@@ -610,7 +636,7 @@ MP_INLINE static int get_bucket(modperl_filter_t *filter)
     }
     else if (MP_FILTER_IS_FLUSH(filter)) {
         MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-                   "read in: FLUSH bucket\n",
+                   "read in: FLUSH bucket",
                    MP_FILTER_NAME(filter->f));
         filter->flush = 1;
         return 0;
@@ -630,9 +656,14 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
     apr_size_t len = 0;
 
     (void)SvUPGRADE(buffer, SVt_PV);
-    SvPOK_only(buffer);
     SvCUR(buffer) = 0;
 
+    /* calling SvPOK_only here may leave buffer an invalid state since
+     * SvPVX may be NULL. But it's very likely that something is copied.
+     * So, we turn the POK flag on here. Later we check if SvPVX is NULL
+     * and turn the flag off again if so. */
+    SvPOK_only(buffer);
+
     /* sometimes the EOS bucket arrives in the same brigade with other
      * buckets, so that particular read() will not return 0 and will
      * be called again if called in the while ($filter->read(...))
@@ -645,7 +676,7 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
     /* modperl_brigade_dump(filter->bb_in, NULL); */
 
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "wanted: %db\n",
+               "wanted: %db",
                MP_FILTER_NAME(filter->f),
                wanted);
 
@@ -653,11 +684,12 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
         if (filter->remaining >= wanted) {
             MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
                        "eating and returning %d [%s]\n\tof "
-                       "remaining %db\n",
+                       "remaining %db",
                        MP_FILTER_NAME(filter->f),
                        wanted,
                        MP_TRACE_STR_TRUNC(filter->pool, filter->leftover, wanted),
                        filter->remaining);
+            SvGROW(buffer, wanted+1);
             sv_catpvn(buffer, filter->leftover, wanted);
             filter->leftover += wanted;
             filter->remaining -= wanted;
@@ -665,9 +697,10 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
         }
         else {
             MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-                       "eating remaining %db\n",
+                       "eating remaining %db",
                        MP_FILTER_NAME(filter->f),
                        filter->remaining);
+            SvGROW(buffer, filter->remaining+1);
             sv_catpvn(buffer, filter->leftover, filter->remaining);
             len = filter->remaining;
             filter->remaining = 0;
@@ -690,7 +723,7 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
         if (filter->rc == APR_SUCCESS) {
             MP_TRACE_f(MP_FUNC,
                        MP_FILTER_NAME_FORMAT
-                       "read in: %s bucket with %db (0x%lx)\n",
+                       "read in: %s bucket with %db (0x%lx)",
                        MP_FILTER_NAME(filter->f),
                        filter->bucket->type->name,
                        buf_len,
@@ -704,6 +737,7 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
         if (buf_len) {
             if ((SvCUR(buffer) + buf_len) >= wanted) {
                 int nibble = wanted - SvCUR(buffer);
+                SvGROW(buffer, SvCUR(buffer)+nibble+1);
                 sv_catpvn(buffer, buf, nibble);
                 filter->leftover = (char *)buf+nibble;
                 filter->remaining = buf_len - nibble;
@@ -712,14 +746,19 @@ MP_INLINE static apr_size_t modperl_filter_read(pTHX_
             }
             else {
                 len += buf_len;
+                SvGROW(buffer, SvCUR(buffer)+buf_len+1);
                 sv_catpvn(buffer, buf, buf_len);
             }
         }
     }
 
+    if (!SvPVX(buffer)) {
+        SvPOK_off(buffer);
+    }
+
     MP_TRACE_f(MP_FUNC,
                MP_FILTER_NAME_FORMAT
-               "return: %db from %d bucket%s [%s]\n\t(%db leftover)\n",
+               "return: %db from %d bucket%s [%s]\n\t(%db leftover)",
                MP_FILTER_NAME(filter->f),
                len, num_buckets, ((num_buckets == 1) ? "" : "s"),
                MP_TRACE_STR_TRUNC(filter->pool, SvPVX(buffer), len),
@@ -740,7 +779,7 @@ MP_INLINE apr_size_t modperl_input_filter_read(pTHX_
         filter->bb_in = apr_brigade_create(filter->pool,
                                            filter->f->c->bucket_alloc);
         MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-                   "retrieving bb: 0x%lx\n",
+                   "retrieving bb: 0x%lx",
                    MP_FILTER_NAME(filter->f),
                    (unsigned long)(filter->bb_in));
         MP_RUN_CROAK(ap_get_brigade(filter->f->next, filter->bb_in,
@@ -846,7 +885,7 @@ MP_INLINE apr_status_t modperl_input_filter_write(pTHX_
     char *copy = apr_pmemdup(filter->pool, buf, *len);
     apr_bucket *bucket = apr_bucket_transient_create(copy, *len, ba);
     MP_TRACE_f(MP_FUNC, MP_FILTER_NAME_FORMAT
-               "write out: %db [%s]:\n",
+               "write out: %db [%s]:",
                MP_FILTER_NAME(filter->f), *len,
                MP_TRACE_STR_TRUNC(filter->pool, copy, *len));
     APR_BRIGADE_INSERT_TAIL(filter->bb_out, bucket);
@@ -874,7 +913,7 @@ apr_status_t modperl_output_filter_handler(ap_filter_t *f,
         MP_TRACE_f(MP_FUNC,
                    MP_FILTER_NAME_FORMAT
                    "write_out: EOS was already sent, "
-                   "passing through the brigade\n",
+                   "passing through the brigade",
                    MP_FILTER_NAME(f));
         return ap_pass_brigade(f->next, bb);
     }
@@ -908,7 +947,7 @@ apr_status_t modperl_input_filter_handler(ap_filter_t *f,
         MP_TRACE_f(MP_FUNC,
                    MP_FILTER_NAME_FORMAT
                    "write out: EOS was already sent, "
-                   "passing through the brigade\n",
+                   "passing through the brigade",
                    MP_FILTER_NAME(f));
         return ap_get_brigade(f->next, bb, input_mode, block, readbytes);
     }
@@ -974,7 +1013,7 @@ static int modperl_filter_add_connection(conn_rec *c,
                 addfunc(handlers[i]->name, NULL, NULL, c);
                 MP_TRACE_f(MP_FUNC,
                            "a non-mod_perl %s handler %s configured "
-                           "(connection)\n", type, handlers[i]->name);
+                           "(connection)", type, handlers[i]->name);
                 continue;
             }
 
@@ -982,7 +1021,7 @@ static int modperl_filter_add_connection(conn_rec *c,
              * configured outside the resource container */
             if (!(handlers[i]->attrs & MP_FILTER_CONNECTION_HANDLER)) {
                 MP_TRACE_f(MP_FUNC,
-                           "%s is not a FilterConnection handler, skipping\n",
+                           "%s is not a FilterConnection handler, skipping",
                            handlers[i]->name);
                 continue;
             }
@@ -1009,14 +1048,14 @@ static int modperl_filter_add_connection(conn_rec *c,
                 }
             }
 
-            MP_TRACE_h(MP_FUNC, "%s handler %s configured (connection)\n",
+            MP_TRACE_h(MP_FUNC, "%s handler %s configured (connection)",
                        type, handlers[i]->name);
         }
 
         return OK;
     }
 
-    MP_TRACE_h(MP_FUNC, "no %s handlers configured (connection)\n", type);
+    MP_TRACE_h(MP_FUNC, "no %s handlers configured (connection)", type);
 
     return DECLINED;
 }
@@ -1044,7 +1083,7 @@ static int modperl_filter_add_request(request_rec *r,
             if ((handlers[i]->attrs & MP_FILTER_HTTPD_HANDLER)) {
                 addfunc(handlers[i]->name, NULL, r, r->connection);
                 MP_TRACE_f(MP_FUNC,
-                           "a non-mod_perl %s handler %s configured (%s)\n",
+                           "a non-mod_perl %s handler %s configured (%s)",
                            type, handlers[i]->name, r->uri);
                 continue;
             }
@@ -1055,7 +1094,7 @@ static int modperl_filter_add_request(request_rec *r,
              */
             if ((handlers[i]->attrs & MP_FILTER_CONNECTION_HANDLER)) {
                 MP_TRACE_f(MP_FUNC,
-                           "%s is not a FilterRequest handler, skipping\n",
+                           "%s is not a FilterRequest handler, skipping",
                            handlers[i]->name);
                 continue;
             }
@@ -1072,7 +1111,7 @@ static int modperl_filter_add_request(request_rec *r,
                 /* XXX: I think this won't work as f->frec->name gets
                  * lowercased when added to the chain */
                 if (*fname == 'M' && strEQ(fname, name)) {
-                    modperl_handler_t *ctx_handler = 
+                    modperl_handler_t *ctx_handler =
                         ((modperl_filter_ctx_t *)f->ctx)->handler;
 
                     if (modperl_handler_equal(ctx_handler, handlers[i])) {
@@ -1090,7 +1129,7 @@ static int modperl_filter_add_request(request_rec *r,
 
             if (registered) {
                 MP_TRACE_f(MP_FUNC,
-                        "%s %s already registered\n",
+                        "%s %s already registered",
                         handlers[i]->name, type);
                 continue;
             }
@@ -1117,14 +1156,14 @@ static int modperl_filter_add_request(request_rec *r,
                 }
             }
 
-            MP_TRACE_h(MP_FUNC, "%s handler %s configured (%s)\n",
+            MP_TRACE_h(MP_FUNC, "%s handler %s configured (%s)",
                        type, handlers[i]->name, r->uri);
         }
 
         return OK;
     }
 
-    MP_TRACE_h(MP_FUNC, "no %s handlers configured (%s)\n",
+    MP_TRACE_h(MP_FUNC, "no %s handlers configured (%s)",
                type, r->uri);
 
     return DECLINED;
@@ -1191,7 +1230,7 @@ void modperl_filter_runtime_add(pTHX_ request_rec *r, conn_rec *c,
                                   modperl_filter_f_cleanup,
                                   apr_pool_cleanup_null);
 
-        /* has to resolve early so we can check for init functions */ 
+        /* has to resolve early so we can check for init functions */
         if (!modperl_mgv_resolve(aTHX_ handler, pool, handler->name, TRUE)) {
             Perl_croak(aTHX_ "unable to resolve handler %s\n",
                        modperl_handler_name(handler));
@@ -1231,7 +1270,7 @@ void modperl_filter_runtime_add(pTHX_ request_rec *r, conn_rec *c,
             }
         }
 
-        MP_TRACE_h(MP_FUNC, "%s handler %s configured (connection)\n",
+        MP_TRACE_h(MP_FUNC, "%s handler %s configured (connection)",
                    type, name);
 
         return;
