@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -30,7 +31,7 @@ static int modperl_gtop_size_string(size_t size, char *size_string)
     }
     else if (size < 1048576) {
         apr_snprintf(size_string, MP_GTOP_SSS, "%dk",
-                     (size + 512) / 1024);
+                     (int)(size + 512) / 1024);
     }
     else if (size < 103809024) {
         apr_snprintf(size_string, MP_GTOP_SSS, "%.1fM",
@@ -38,7 +39,7 @@ static int modperl_gtop_size_string(size_t size, char *size_string)
     }
     else {
         apr_snprintf(size_string, MP_GTOP_SSS, "%dM",
-                     (size + 524288) / 1048576);
+                     (int)(size + 524288) / 1048576);
     }
 
     return 1;
@@ -52,7 +53,7 @@ static apr_status_t modperl_gtop_exit(void *data)
 
 modperl_gtop_t *modperl_gtop_new(apr_pool_t *p)
 {
-    modperl_gtop_t *gtop = 
+    modperl_gtop_t *gtop =
         (modperl_gtop_t *)apr_pcalloc(p, sizeof(*gtop));
 
     gtop->pid = getpid();
@@ -82,8 +83,8 @@ void modperl_gtop_get_proc_mem_after(modperl_gtop_t *gtop)
 #define SS_TYPE_AFTER  2
 #define SS_TYPE_DIFF   3
 
-/* 
- * XXX: this is pretty ugly, 
+/*
+ * XXX: this is pretty ugly,
  * but avoids allocating buffers for the size string
  */
 static void modperl_gtop_proc_mem_size_string(modperl_gtop_t *gtop, int type)
@@ -109,7 +110,7 @@ static void modperl_gtop_proc_mem_size_string(modperl_gtop_t *gtop, int type)
 #undef ss_call
 }
 
-void modperl_gtop_report_proc_mem(modperl_gtop_t *gtop, 
+void modperl_gtop_report_proc_mem(modperl_gtop_t *gtop,
                                   char *when, const char *func, char *msg)
 {
 #define ss_item(item) gtop->proc_mem_ss.item
