@@ -1,8 +1,9 @@
-/* Copyright 2002-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -119,7 +120,7 @@ static apr_status_t modperl_module_config_obj_cleanup(void *data)
 
     modperl_svptr_table_delete(aTHX_ cleanup->table, cleanup->ptr);
 
-    MP_TRACE_c(MP_FUNC, "deleting ptr 0x%lx from table 0x%lx\n",
+    MP_TRACE_c(MP_FUNC, "deleting ptr 0x%lx from table 0x%lx",
                (unsigned long)cleanup->ptr,
                (unsigned long)cleanup->table);
 
@@ -210,7 +211,7 @@ static void *modperl_module_config_merge(apr_pool_t *p,
         int count;
         dSP;
 
-        MP_TRACE_c(MP_FUNC, "calling %s->%s\n",
+        MP_TRACE_c(MP_FUNC, "calling %s->%s",
                    SvCLASS(base_obj), modperl_mgv_last_name(method));
 
         ENTER;SAVETMPS;
@@ -249,7 +250,7 @@ static void *modperl_module_config_merge(apr_pool_t *p,
        modperl_interp_unselect(interp); */
     MP_PERL_CONTEXT_RESTORE;
 #endif
-    
+
     return (void *)mrg;
 }
 
@@ -295,7 +296,7 @@ modperl_module_config_create_obj(pTHX_
         return NULL;
     }
 
-    MP_TRACE_c(MP_FUNC, "%s cfg=0x%lx for %s.%s\n",
+    MP_TRACE_c(MP_FUNC, "%s cfg=0x%lx for %s.%s",
                method, (unsigned long)cfg,
                mname, parms->cmd->name);
 
@@ -387,7 +388,7 @@ static const char *modperl_module_cmd_take123(cmd_parms *parms,
          * needed by the Perl callback.
          */
         if (!scfg) {
-            scfg = modperl_config_srv_new(p);
+            scfg = modperl_config_srv_new(p, s);
             modperl_set_module_config(s->module_config, scfg);
             scfg->server = s;
         }
@@ -419,7 +420,7 @@ static const char *modperl_module_cmd_take123(cmd_parms *parms,
     }
 
     if (obj) {
-        MP_TRACE_c(MP_FUNC, "found per-dir obj=0x%lx for %s.%s\n",
+        MP_TRACE_c(MP_FUNC, "found per-dir obj=0x%lx for %s.%s",
                    (unsigned long)obj,
                    info->modp->name, cmd->name);
     }
@@ -439,7 +440,7 @@ static const char *modperl_module_cmd_take123(cmd_parms *parms,
         }
 
         if (srv_obj) {
-            MP_TRACE_c(MP_FUNC, "found per-srv obj=0x%lx for %s.%s\n",
+            MP_TRACE_c(MP_FUNC, "found per-srv obj=0x%lx for %s.%s",
                        (unsigned long)srv_obj,
                        info->modp->name, cmd->name);
         }
@@ -646,7 +647,7 @@ static const char *modperl_module_add_cmds(apr_pool_t *p, server_rec *s,
 #ifdef USE_ITHREADS
     MP_dSCFG(s);
     dTHXa(scfg->mip->parent->perl);
-#endif 
+#endif
     module_cmds = (AV*)SvRV(mod_cmds);
 
     fill = AvFILL(module_cmds);
@@ -771,7 +772,7 @@ static modperl_mgv_t *modperl_module_fetch_method(pTHX_
     HV *stash = gv_stashpv(modp->name, FALSE);
     GV *gv = gv_fetchmethod_autoload(stash, method, FALSE);
 
-    MP_TRACE_c(MP_FUNC, "looking for method %s in package `%s'...%sfound\n", 
+    MP_TRACE_c(MP_FUNC, "looking for method %s in package `%s'...%sfound",
                method, modp->name,
                MP_isGV(gv) ? "" : "not ");
 
@@ -808,7 +809,7 @@ const char *modperl_module_add(apr_pool_t *p, server_rec *s,
     /* use this slot for our context */
     modp->dynamic_load_handle = minfo;
 
-    /* 
+    /*
      * XXX: we should lookup here if the Perl methods exist,
      * and set these pointers only if they do.
      */
@@ -853,7 +854,7 @@ const char *modperl_module_add(apr_pool_t *p, server_rec *s,
     apr_hash_set(scfg->modules, apr_pstrdup(p, name), APR_HASH_KEY_STRING, modp);
 
 #ifdef USE_ITHREADS
-    /* 
+    /*
      * if the Perl module is loaded in the base server and a vhost
      * has configuration directives from that module, but no mod_perl.c
      * directives, scfg == NULL when modperl_module_cmd_take123 is run.
@@ -869,7 +870,7 @@ const char *modperl_module_add(apr_pool_t *p, server_rec *s,
     return NULL;
 }
 
-SV *modperl_module_config_get_obj(pTHX_ SV *pmodule, server_rec *s, 
+SV *modperl_module_config_get_obj(pTHX_ SV *pmodule, server_rec *s,
                                   ap_conf_vector_t *v)
 {
     MP_dSCFG(s);
