@@ -1,8 +1,9 @@
-/* Copyright 2001-2004 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -33,16 +34,33 @@ static modperl_perl_core_global_t MP_perl_core_global_entries[] = {
     { NULL },
 };
 
+XS(XS_ModPerl__Util_exit); /* prototype to pass -Wmissing-prototypes */
+XS(XS_ModPerl__Util_exit)
+{
+    dXSARGS;
+    int status;
+    if (items < 0 || items > 1) {
+        Perl_croak(aTHX_ "Usage: ModPerl::Util::exit(status=0)");
+    }
+    /* default: 0 */
+    status = items < 1 ? 0 : (int)SvIV(ST(0));
+    modperl_perl_exit(aTHX_ status);
+
+    XSRETURN_EMPTY;
+}
+
 void modperl_perl_core_global_init(pTHX)
 {
     modperl_perl_core_global_t *cglobals = MP_perl_core_global_entries;
 
     while (cglobals->name) {
         GV *gv = gv_fetchpv(cglobals->core_name, TRUE, SVt_PVCV);
-        GvCV(gv) = get_cv(cglobals->sub_name, TRUE);
+        GvCV_set(gv, get_cv(cglobals->sub_name, TRUE));
         GvIMPORTED_CV_on(gv);
         cglobals++;
     }
+
+    newXS("ModPerl::Util::exit", XS_ModPerl__Util_exit, __FILE__);
 }
 
 static void modperl_perl_ids_get(modperl_perl_ids_t *ids)
@@ -53,22 +71,23 @@ static void modperl_perl_ids_get(modperl_perl_ids_t *ids)
 #endif
 #ifndef WIN32
     ids->uid  = getuid();
-    ids->euid = geteuid(); 
-    ids->gid  = getgid(); 
-    ids->gid  = getegid(); 
+    ids->euid = geteuid();
+    ids->gid  = getgid();
+    ids->egid  = getegid();
 
-    MP_TRACE_r(MP_FUNC, 
+    MP_TRACE_r(MP_FUNC,
                "pid=%d, "
 #ifdef MP_MAINTAIN_PPID
                "ppid=%d, "
 #endif
-               "uid=%d, euid=%d, gid=%d, egid=%d\n",
+               "uid=%" Uid_t_f ", euid=%" Uid_t_f ", "
+               "gid=%" Gid_t_f ", egid=%" Gid_t_f,
                (int)ids->pid,
 #ifdef MP_MAINTAIN_PPID
                (int)ids->ppid,
 #endif
-               (int)ids->uid, (int)ids->euid,
-               (int)ids->gid, (int)ids->egid);
+               ids->uid, ids->euid,
+               ids->gid, ids->egid);
 #endif /* #ifndef WIN32 */
 }
 
@@ -104,8 +123,8 @@ void modperl_perl_init_ids_server(server_rec *s)
     modperl_perl_ids_t ids;
     modperl_perl_ids_get(&ids);
 #ifdef USE_ITHREADS
-     modperl_interp_mip_walk_servers(NULL, s,
-                                     modperl_perl_init_ids_mip,
+    modperl_interp_mip_walk_servers(NULL, s,
+                                    modperl_perl_init_ids_mip,
                                     (void*)&ids);
 #else
     modperl_perl_init_ids(aTHX_ &ids);
@@ -115,7 +134,7 @@ void modperl_perl_init_ids_server(server_rec *s)
 void modperl_perl_destruct(PerlInterpreter *perl)
 {
     char **orig_environ = NULL;
-    PTR_TBL_t *module_commands; 
+    PTR_TBL_t *module_commands;
     dTHXa(perl);
 
     PERL_SET_CONTEXT(perl);
@@ -181,8 +200,7 @@ void modperl_perl_call_endav(pTHX)
      }
 }
 
-#if !(PERL_REVISION == 5 && ( PERL_VERSION < 8 ||    \
-    (PERL_VERSION == 8 && PERL_SUBVERSION == 0))) && \
+#if !(MP_PERL_VERSION_AT_MOST(5, 8, 0)) && \
     (defined(USE_HASH_SEED) || defined(USE_HASH_SEED_EXPLICIT))
 #define MP_NEED_HASH_SEED_FIXUP
 #endif
@@ -193,7 +211,7 @@ static bool MP_init_hash_seed_set = FALSE;
 #endif
 
 /* see modperl_hash_seed_set() */
-void modperl_hash_seed_init(apr_pool_t *p) 
+void modperl_hash_seed_init(apr_pool_t *p)
 {
 #ifdef MP_NEED_HASH_SEED_FIXUP
     char *s;
@@ -235,11 +253,11 @@ void modperl_hash_seed_init(apr_pool_t *p)
  * it randomizes if perl was compiled with ccflags -DUSE_HASH_SEED
  * or -DUSE_HASH_SEED_EXPLICIT, in which case we need to tell perl
  * to use the same seed everywhere */
-void modperl_hash_seed_set(pTHX) 
+void modperl_hash_seed_set(pTHX)
 {
 #ifdef MP_NEED_HASH_SEED_FIXUP
     if (MP_init_hash_seed_set) {
-#if PERL_REVISION == 5 && PERL_VERSION == 8 && PERL_SUBVERSION == 1
+#if MP_PERL_VERSION(5, 8, 1)
         PL_hash_seed       = MP_init_hash_seed;
         PL_hash_seed_set   = MP_init_hash_seed_set;
 #else
