@@ -29,8 +29,6 @@ END {
 
 test_apache_resource();
 
-test_apache_size_limit();
-
 test_apache_status();
 
 test_loglevel();
@@ -61,19 +59,6 @@ sub test_apache_resource {
     require Apache2::Resource;
 }
 
-sub test_apache_size_limit {
-    # would be nice to write a real test, but for now just see that we
-    # can load it for non-threaded mpms on supported platforms
-    require Apache2::MPM;
-    return if Apache2::MPM->is_threaded;
-    eval { require Apache2::SizeLimit };
-    if ($@) {
-        # unsupported platform
-        die $@ unless $@ =~ /Apache2::SizeLimit not implemented on/
-            or $@ =~ /you must install BSD::Resource/;
-    }
-}
-
 sub test_apache_status {
     ### Apache2::Status tests
     require Apache2::Status;
