@@ -6,16 +6,16 @@ use warnings FATAL => 'all';
 use Apache::Test;
 
 use APR::Table ();
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
 
-    $r->notes->set(url => $ENV{REQUEST_URI});
+    $r->notes->set(headerparser => 'set');
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub response {
@@ -23,9 +23,9 @@ sub response {
 
     plan $r, tests => 1;
 
-    ok $r->notes->get('url') eq $r->uri;
+    ok $r->notes->get('headerparser') eq 'set';
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
