@@ -3,16 +3,22 @@ package TestPreConnection::note;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::Connection ();
+use Apache2::Connection ();
 
-use Apache::Const -compile => qw(OK);
+use Apache::TestTrace;
+
+use Apache2::Const -compile => qw(OK);
 
 sub handler {
-    my Apache::Connection $c = shift;
+    my Apache2::Connection $c = shift;
 
-    $c->notes->set(preconnection => 'ok');
+    my $ip = $c->remote_ip;
 
-    return Apache::OK;
+    debug "ip: $ip";
+
+    $c->notes->set(preconnection => $ip);
+
+    return Apache2::Const::OK;
 }
 
 sub response {
@@ -21,7 +27,7 @@ sub response {
     $r->content_type('text/plain');
     $r->print($r->connection->notes->get('preconnection') || '');
 
-    return Apache::OK
+    return Apache2::Const::OK
 }
 
 1;
@@ -29,7 +35,7 @@ __END__
 <NoAutoConfig>
   <VirtualHost TestPreConnection::note>
     PerlPreConnectionHandler TestPreConnection::note
-  
+
     <Location /TestPreConnection__note>
       SetHandler modperl
       PerlResponseHandler TestPreConnection::note::response
