@@ -8,34 +8,40 @@ package TestProtocol::echo_block;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::Connection ();
+use Apache2::Connection ();
 use APR::Socket ();
 
-use Apache::Const -compile => 'OK';
+use TestCommon::Utils;
+
+use Apache2::Const -compile => 'OK';
 use APR::Const    -compile => qw(SO_NONBLOCK);
 
 use constant BUFF_LEN => 1024;
 
 sub handler {
-    my Apache::Connection $c = shift;
+    my Apache2::Connection $c = shift;
     my APR::Socket $socket = $c->client_socket;
 
     # starting from Apache 2.0.49 several platforms require you to set
     # the socket to a blocking IO mode
-    my $nonblocking = $socket->opt_get(APR::SO_NONBLOCK);
+    my $nonblocking = $socket->opt_get(APR::Const::SO_NONBLOCK);
     if ($nonblocking) {
-        $socket->opt_set(APR::SO_NONBLOCK => 0);
+        $socket->opt_set(APR::Const::SO_NONBLOCK, 0);
 
         # test that we really *are* in the blocking mode
-        !$socket->opt_get(APR::SO_NONBLOCK)
+        !$socket->opt_get(APR::Const::SO_NONBLOCK)
             or die "failed to set blocking mode";
     }
 
-    while ($socket->recv(my $buff, BUFF_LEN)) {
-        $socket->send($buff);
+    while ($socket->recv(my $buffer, BUFF_LEN)) {
+
+        die "recv() has returned untainted data:"
+            unless TestCommon::Utils::is_tainted($buffer);
+
+        $socket->send($buffer);
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
