@@ -5,17 +5,19 @@ package TestAPI::content_encoding;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestUtil ();
+use Apache2::RequestRec ();
+use Apache2::RequestUtil ();
 
-use Apache::Const -compile => qw(OK DECLINED);
+use TestCommon::Utils ();
+
+use Apache2::Const -compile => qw(OK DECLINED M_POST);
 
 sub handler {
     my $r = shift;
 
-    return Apache::DECLINED unless $r->method_number == Apache::M_POST;
+    return Apache2::Const::DECLINED unless $r->method_number == Apache2::Const::M_POST;
 
-    my $data = ModPerl::Test::read_post($r);
+    my $data = TestCommon::Utils::read_post($r);
 
     require Compress::Zlib;
 
@@ -24,7 +26,7 @@ sub handler {
 
     $r->print(Compress::Zlib::memGzip($data));
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
