@@ -6,20 +6,20 @@ use warnings FATAL => 'all';
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
 use TestAPRlib::finfo;
 
 use APR::Finfo ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 use APR::Const    -compile => qw(FINFO_NORM);
 
 sub handler {
     my $r = shift;
 
-    my $tests = 2 + TestAPRlib::finfo::num_of_tests();
+    my $tests = 1 + TestAPRlib::finfo::num_of_tests();
     plan $r, tests => $tests;
 
     {
@@ -30,19 +30,11 @@ sub handler {
         ok $isa;
     }
 
-    {
-        my $pool = $r->finfo->pool;
-        my $isa = $pool->isa('APR::Pool');
-
-        t_debug "\$r->finfo->pool $pool";
-        ok $isa;
-    }
-
     # a test assigning to $r->finfo is in TestAPI::request_rec
 
     TestAPRlib::finfo::test();
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
