@@ -3,8 +3,12 @@ package TestModperl::getc;
 use strict;
 use warnings FATAL => 'all';
 
+use Apache2::RequestIO ();
+
 use Apache::Test;
 
+use Apache2::Const -compile => 'OK';
+
 sub handler {
     my $r = shift;
 
@@ -18,7 +22,7 @@ sub handler {
 
     untie *STDIN;
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
