@@ -3,12 +3,12 @@ package TestModperl::readline;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestIO ();
-use Apache::compat (); #XXX
+use Apache2::RequestIO ();
+use Apache2::compat (); #XXX
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -22,7 +22,7 @@ sub handler {
 
     untie *STDIN;
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
