@@ -3,9 +3,11 @@ package TestModules::cgi;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::compat ();
+use Apache2::compat ();
 use CGI ();
 
+use Apache2::Const -compile => 'OK';
+
 sub handler {
     my $r = shift;
 
@@ -13,9 +15,8 @@ sub handler {
         die "\$ENV{MOD_PERL} is not set";
     }
 
-    my $gw = $ENV{GATEWAY_INTERFACE} || '';
-    unless ($gw eq 'CGI-Perl/1.1') {
-        die "\$ENV{GATEWAY_INTERFACE} is not properly set ($gw)";
+    unless ($ENV{MOD_PERL_API_VERSION} == 2) {
+        die "\$ENV{MOD_PERL_API_VERSION} is not set";
     }
 
     if ($CGI::Q) {
@@ -47,10 +48,10 @@ sub handler {
         print "no param or upload data\n";
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
 __END__
 SetHandler perl-script
-PerlOptions +GlobalRequest
+PerlOptions -SetupEnv
