@@ -3,10 +3,10 @@ package TestModules::cgipost;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::compat ();
+use Apache2::compat ();
 use CGI ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -16,7 +16,7 @@ sub handler {
 
     print join ":", map { $cgi->param($_) } $cgi->param;
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
