@@ -39,9 +39,11 @@ typedef struct {
  */
 
 #ifndef MP_SOURCE_SCAN
+#ifdef USE_ITHREADS
 #include "apr_optional.h"
-static
 APR_OPTIONAL_FN_TYPE(modperl_interp_unselect) *modperl_opt_interp_unselect;
+APR_OPTIONAL_FN_TYPE(modperl_thx_interp_get) *modperl_opt_thx_interp_get;
+#endif
 #endif
 
 #define MP_APR_POOL_SV_HAS_OWNERSHIP(sv) mpxs_pool_is_custom(sv)
@@ -64,7 +66,7 @@ APR_OPTIONAL_FN_TYPE(modperl_interp_unselect) *modperl_opt_interp_unselect;
     mg_free(acct->sv);                                              \
     SvIVX(acct->sv) = 0;                                            \
 } STMT_END
-    
+
 #ifdef USE_ITHREADS
 
 #define MP_APR_POOL_SV_DROPS_OWNERSHIP(acct) STMT_START {               \
@@ -95,8 +97,10 @@ APR_OPTIONAL_FN_TYPE(modperl_interp_unselect) *modperl_opt_interp_unselect;
     /* make sure interpreter is not putback into the mip                \
      * until this cleanup has run.                                      \
      */                                                                 \
-    if ((acct->interp = MP_THX_INTERP_GET(aTHX))) {                     \
-        acct->interp->refcnt++;                                         \
+    if (modperl_opt_thx_interp_get) {                                   \
+        if ((acct->interp = modperl_opt_thx_interp_get(aTHX))) {        \
+            acct->interp->refcnt++;                                     \
+        }                                                               \
     }                                                                   \
 } STMT_END
 
@@ -152,7 +156,7 @@ static MP_INLINE SV *mpxs_apr_pool_create(pTHX_ SV *parent_pool_obj)
     apr_pool_t *parent_pool = mpxs_sv_object_deref(parent_pool_obj, apr_pool_t);
     apr_pool_t *child_pool  = NULL;
 
-    MP_POOL_TRACE(MP_FUNC, "parent pool 0x%lx\n", (unsigned long)parent_pool);
+    MP_POOL_TRACE(MP_FUNC, "parent pool 0x%l", (unsigned long)parent_pool);
     (void)apr_pool_create(&child_pool, parent_pool);
 
 #if APR_POOL_DEBUG
@@ -176,11 +180,11 @@ static MP_INLINE SV *mpxs_apr_pool_create(pTHX_ SV *parent_pool_obj)
         apr_pool_t *pp;
 
         while ((pp = apr_pool_parent_get(p))) {
-            MP_POOL_TRACE(MP_FUNC, "parent 0x%lx, child 0x%lx\n",
+            MP_POOL_TRACE(MP_FUNC, "parent 0x%lx, child 0x%lx",
                     (unsigned long)pp, (unsigned long)p);
 
             if (apr_pool_is_ancestor(pp, p)) {
-                MP_POOL_TRACE(MP_FUNC, "0x%lx is a subpool of 0x%lx\n",
+                MP_POOL_TRACE(MP_FUNC, "0x%lx is a subpool of 0x%lx",
                         (unsigned long)p, (unsigned long)pp);
             }
             p = pp;
@@ -217,7 +221,7 @@ static MP_INLINE SV *mpxs_apr_pool_create(pTHX_ SV *parent_pool_obj)
         if (parent_pool) {
             mpxs_add_pool_magic(rv, parent_pool_obj);
         }
-        
+
         return rv;
     }
 }
@@ -335,8 +339,10 @@ static MP_INLINE void mpxs_apr_pool_cleanup_register(pTHX_ apr_pool_t *p,
     /* make sure interpreter is not putback into the mip
      * until this cleanup has run.
      */
-    if ((data->interp = MP_THX_INTERP_GET(data->perl))) {
-        data->interp->refcnt++;
+    if (modperl_opt_thx_interp_get) {
+        if ((data->interp = modperl_opt_thx_interp_get(data->perl))) {
+            data->interp->refcnt++;
+        }
     }
 #endif
 
@@ -374,4 +380,3 @@ static MP_INLINE void mpxs_apr_pool_DESTROY(pTHX_ SV *obj)
         apr_pool_destroy(p);
     }
 }
-
