@@ -116,3 +116,12 @@ apr_status_t mpxs_APR__Socket_poll(apr_socket_t *socket,
 
     return apr_poll(&fd, 1, &nsds, timeout);
 }
+
+#ifndef WIN32
+static MP_INLINE int mpxs_APR__Socket_fileno(pTHX_ apr_socket_t *sock)
+{
+    apr_os_sock_t s;
+    apr_os_sock_get(&s, sock);
+    return s;
+}
+#endif
